# Anti-Viral Protocol ![LOGO](https://i.imgur.com/TupVtfV.png)
## A Game by ![Team De-Bug](https://i.imgur.com/C3eA4g8.png)
***
### Main Code And Logic by Marudhu Paandian K
### Sound and Level Design by K.A. Shabesa
### Visuals and Art by Rishi Menon


You can find the wiki [here](https://github.com/RishiMenon2004/Anti-Viral-Protocol/wiki) for things such as controls, story and gamplay.
